%_compat_el5_build

%{!?scl:%global scl autotools-git}

# Detect gcc version, (workaround) see the bug #429880
%global gcc_version  %(gcc -dumpversion || echo "666")

%global git_hash        97f0
%global upstream_vr     2.4.4.16-%{git_hash}

%{?scl:%scl_package libtool}

Summary: The GNU Portable Library Tool
Name:    %{?scl_prefix}libtool
Version: 2.4.5~git
Release: 1.%{git_hash}%{?dist}
License: GPLv2+ and LGPLv2+ and GFDL
URL:     http://www.gnu.org/software/libtool/
Group:   Development/Tools

Source:  libtool-%{upstream_vr}.tar.gz

# /usr/bin/libtool includes paths within gcc's versioned directories
# Libtool must be rebuilt whenever a new upstream gcc is built
Requires: gcc = %{gcc_version}
Requires: %{scl_prefix}autoconf, %{scl_prefix}automake, sed, tar, findutils
Requires(post):  /sbin/install-info
Requires(preun): /sbin/install-info

BuildRequires: texinfo

%{?scl:
BuildRequires: scl-utils-build
Requires:%scl_runtime
}

%if ! 0%{?buildroot:1}
# HACK!  This should be truth only for RHEL5, so benefit from
# this %%if for defining (otherwise undefined) macro for this platform.
%global rhel 5
BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%endif

# make sure we can configure all supported langs
BuildRequires: libstdc++-devel, gcc-gfortran


%description
GNU Libtool is a set of shell scripts which automatically configure UNIX and
UNIX-like systems to generically build shared libraries. Libtool provides a
consistent, portable interface which simplifies the process of using shared
libraries.

If you are developing programs which will use shared libraries, but do not use
the rest of the GNU Autotools (such as GNU Autoconf and GNU Automake), you
should install the libtool package.

The libtool package also includes all files needed to integrate the GNU
Portable Library Tool (libtool) and the GNU Libtool Dynamic Module Loader
(ltdl) into a package built using the GNU Autotools (including GNU Autoconf
and GNU Automake).


%package ltdl
Summary:  Runtime libraries for GNU Libtool Dynamic Module Loader
Group:    System Environment/Libraries
Provides: %{name}-libs = %{version}-%{release}
License:  LGPLv2+
Requires(post):  /sbin/ldconfig
Requires(postun):  /sbin/ldconfig
%{?scl:Requires:%scl_runtime}

%description ltdl
The libtool-ltdl package contains the GNU Libtool Dynamic Module Loader, a
library that provides a consistent, portable interface which simplifies the
process of using dynamic modules.

These runtime libraries are needed by programs that link directly to the
system-installed ltdl libraries; they are not needed by software built using
the rest of the GNU Autotools (including GNU Autoconf and GNU Automake).


%package ltdl-devel
Summary: Tools needed for development using the GNU Libtool Dynamic Module Loader
Group:    Development/Libraries
Requires: %{name}-ltdl = %{version}-%{release}
License:  LGPLv2+
%{?scl:Requires:%scl_runtime}

%description ltdl-devel
Static libraries and header files for development with ltdl.


%prep
%setup -q -n libtool-%{upstream_vr}

# to use this, we should 100% *know* what the patches do
find -exec touch --date=`date -I` {} +


%build
export CC=gcc
export CXX=g++
export F77=gfortran
export CFLAGS="$RPM_OPT_FLAGS -fPIC"

%configure  --prefix=%{_prefix}                 \
            --exec-prefix=%{_prefix}            \
            --bindir=%{_bindir}                 \
            --sbindir=%{_sbindir}               \
            --sysconfdir=%{_sysconfdir}         \
            --datadir=%{_datadir}               \
            --includedir=%{_includedir}         \
            --libdir=%{_libdir}                 \
            --libexecdir=%{_libexecdir}         \
            --localstatedir=%{_localstatedir}   \
            --mandir=%{_mandir}                 \
            --infodir=%{_infodir}               \
            --host= --build= --target=

make %{?_smp_mflags}


%check
# make check VERBOSE=yes


%install
%if 0%{?rhel} == 5
rm -rf %{builroot}
%endif
make install DESTDIR=%{buildroot}

# info's TOP dir (by default owned by info)
rm -f %{buildroot}%{_infodir}/dir

# *.la *.a files generated by libtool shouldn't be distributed (and the
# `./configure --disable-static' breaks testsuite)
rm -f %{buildroot}%{_libdir}/libltdl.{a,la}


%post
/sbin/install-info %{_infodir}/libtool.info.gz %{_infodir}/dir || :


%post ltdl -p /sbin/ldconfig


%preun
if [ "$1" = 0 ]; then
   /sbin/install-info --delete %{_infodir}/libtool.info.gz %{_infodir}/dir || :
fi


%postun ltdl -p /sbin/ldconfig


%files
%doc AUTHORS COPYING NEWS README THANKS TODO ChangeLog*
%{_infodir}/libtool.info*.gz
%{_mandir}/man1/libtool.1*
%{_mandir}/man1/libtoolize.1*
%{_bindir}/libtool
%{_bindir}/libtoolize
%{_datadir}/aclocal/*.m4
%exclude %{_datadir}/libtool/libltdl
%{_datadir}/libtool

%files ltdl
%doc libltdl/COPYING.LIB
%{_libdir}/libltdl.so.*

%files ltdl-devel
%doc libltdl/README
%{_datadir}/libtool/libltdl
%{_includedir}/ltdl.h
%{_includedir}/libltdl
# .so files without version must be in -devel subpackage
%{_libdir}/libltdl.so

%changelog
* Sun Jul 13 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-8.444.28.053d
- rebuild for new gcc in F19, second try

* Fri Jul 11 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-7.444.28.053d
- rebuild for new gcc in F19

* Sat Jun 28 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-6.444.28.053d
- rebuild for gcc 4.8.3
- gcc-java removed from Fedora completely (#1106080)

* Thu May 29 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-5.444.28.053d
- release bump for %%_compat_el5_build

* Thu Apr 17 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-4.444.28.053d
- merge fixes/hakcs from other specs

* Mon Mar 24 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-3.444.28.053d
- make spec RHEL5 friendly

* Fri Mar 21 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-2.444.28.053d
- build require scl-utils and scl-utils-build properly

* Wed Mar 19 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-1.444.28.053d
- SCL-ized spec file from Rawhide, disabled testsuite for now
